#[non_exhaustive]pub enum BackendErrorReason {
InvalidOutput,
PanicContained,
Internal,
}Expand description
Backend-origin failure reasons.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InvalidOutput
A backend returned an output shape that violates the operation contract.
PanicContained
A panic firewall or equivalent adapter guard caught an unexpected fault.
Internal
A backend reported a fixed, redacted internal failure.