#[non_exhaustive]pub enum BufferOwner {
Caller,
OperationLayer,
OperationContract,
NativeAdapter,
ManagedRuntime,
PlatformProvider,
}Expand description
Layer responsible for a material buffer at an operation boundary.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Caller
The caller owns borrowed input storage.
OperationLayer
The semantic Rust operation owns a result or temporary.
OperationContract
The protobuf contract owns an encoded request or response buffer.
NativeAdapter
A C ABI or JNI adapter owns native memory for a caller.
ManagedRuntime
A managed SDK/runtime owns memory Rust cannot deterministically wipe.
PlatformProvider
A platform provider owns non-exportable key material.