#[non_exhaustive]pub enum ExportPolicy {
Public,
SecretOwnerRequired,
NonExportable,
}Expand description
Whether material may cross the operation boundary.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Public
Public or ciphertext material may be returned without restriction.
SecretOwnerRequired
Secret bytes may be returned only through an explicitly secret owner.
NonExportable
Provider-resident material must not be exported as raw bytes.