#[non_exhaustive]pub enum OutputMaterial {
Public,
SensitivePublic,
Secret,
Mixed,
}Expand description
Security-relevant class of an operation result.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Public
Digest, signature, public key, boolean, or other public result.
SensitivePublic
Ciphertext or wrapped material that remains privacy-sensitive.
Secret
A private key, plaintext, shared secret, derived key, or seed.
Mixed
A structured result containing both public and secret fields.