#[non_exhaustive]pub enum VerifierError {
VerifyFailed {
algorithm: Algorithm,
kind: VerifierFailureKind,
source: AlgorithmError,
},
}Expand description
Error returned when a verification operation fails.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
VerifyFailed
Verification failed for the given algorithm.
Fields

kind: VerifierFailureKindThe category of failure.

source: AlgorithmErrorThe underlying dispatch error.
Implementations
Sourceimpl VerifierError
impl VerifierError
Sourcepub fn is_signature_invalid(&self) -> bool
pub fn is_signature_invalid(&self) -> bool
True when the failure means the signature itself is invalid (as opposed to an unsupported algorithm or malformed input).